@@ -4,6 +4,7 @@ import json
 import types
 import re
 import base64
+from BaseHTTPServer import BaseHTTPRequestHandler
 
 from .decorators import _property
 
@@ -268,76 +269,6 @@ class Response(Http):
     an instance of this class is used to create the text response that will be sent 
     back to the client
     """
-    statuses = {
-        100: 'Continue',
-        101: 'Switching Protocols',
-        102: 'Processing', # RFC2518
-        200: 'OK',
-        201: 'Created',
-        202: 'Accepted',
-        203: 'Non-Authoritative Information',
-        204: 'No Content',
-        205: 'Reset Content',
-        206: 'Partial Content',
-        207: 'Multi-Status', # RFC4918
-        208: 'Already Reported', # RFC5842
-        226: 'IM Used', # RFC3229
-        300: 'Multiple Choices',
-        301: 'Moved Permanently',
-        302: 'Found',
-        303: 'See Other',
-        304: 'Not Modified',
-        305: 'Use Proxy',
-        306: 'Reserved',
-        307: 'Temporary Redirect',
-        308: 'Permanent Redirect', # RFC-reschke-http-status-308-07
-        400: 'Bad Request',
-        401: 'Unauthorized',
-        402: 'Payment Required',
-        403: 'Forbidden',
-        404: 'Not Found',
-        405: 'Method Not Allowed',
-        406: 'Not Acceptable',
-        407: 'Proxy Authentication Required',
-        408: 'Request Timeout',
-        409: 'Conflict',
-        410: 'Gone',
-        411: 'Length Required',
-        412: 'Precondition Failed',
-        413: 'Request Entity Too Large',
-        414: 'Request-URI Too Long',
-        415: 'Unsupported Media Type',
-        416: 'Requested Range Not Satisfiable',
-        417: 'Expectation Failed',
-        418: 'I\'m a teapot', # RFC2324
-        422: 'Unprocessable Entity', # RFC4918
-        423: 'Locked', # RFC4918
-        424: 'Failed Dependency', # RFC4918
-        425: 'Reserved for WebDAV advanced collections expired proposal', # RFC2817
-        426: 'Upgrade Required', # RFC2817
-        428: 'Precondition Required', # RFC6585
-        429: 'Too Many Requests', # RFC6585
-        431: 'Request Header Fields Too Large', # RFC6585
-        500: 'Internal Server Error',
-        501: 'Not Implemented',
-        502: 'Bad Gateway',
-        503: 'Service Unavailable',
-        504: 'Gateway Timeout',
-        505: 'HTTP Version Not Supported',
-        506: 'Variant Also Negotiates (Experimental)', # RFC2295
-        507: 'Insufficient Storage', # RFC4918
-        508: 'Loop Detected', # RFC5842
-        510: 'Not Extended', # RFC2774
-        511: 'Network Authentication Required', # RFC6585
-    }
-    """default status code messages
-
-    shamefully ripped from Symfony HttpFoundation Response (shoulders of giants)
-    https://github.com/symfony/HttpFoundation/blob/master/Response.php
-    """
-
-    body_generator = None
-
     @property
     def code(self):
         """the http status code to return to the client, by default, 200 if a body is present otherwise 204"""
@@ -358,7 +289,9 @@ class Response(Http):
     def status(self):
         if not getattr(self, '_status', None):
             c = self.code
-            msg = self.statuses.get(self.code, "UNKNOWN")
+            status_tuple = BaseHTTPRequestHandler.responses.get(self.code)
+            msg = "UNKNOWN"
+            if status_tuple: msg = status_tuple[0]
             self._status = msg
 
         return self._status
