@@ -1,22 +1,28 @@
 import os
 
-from ..http import Request
+from ..http import Request, Response
 from ..call import Call
 
+
 class BaseInterface(object):
     """all interfaces should extend this class to be able to interact correctly
     with the server"""
-    def __init__(self, controller_prefix, request_class, call_class, **kwargs):
+    def __init__(self, controller_prefix, request_class, response_class, call_class, **kwargs):
         self.controller_prefix = controller_prefix
         self.request_class = request_class
+        self.response_class = response_class
         self.call_class = call_class
 
     def create_request(self, raw_request, **kwargs):
         raise NotImplemented()
 
+    def create_response(self, **kwargs):
+        return self.response_class()
+
     def create_call(self, raw_request, **kwargs):
         c = self.call_class(self.controller_prefix)
         c.request = self.create_request(raw_request, **kwargs)
+        c.response = self.create_response(**kwargs)
         return c
 
     def handle(self, raw_request=None, **kwargs):
@@ -40,11 +46,16 @@ class BaseServer(object):
     """the endpoints.http.Request compatible class that should be used to make
     Request() instances"""
 
+    response_class = Response
+    """the endpoints.http.Response compatible class that should be used to make
+    Response() instances"""
+
     call_class = Call
     """the endpoints.call.Call compatible class that should be used to make a
     Call() instance"""
 
-    def __init__(self, controller_prefix='', interface_class=None, server_class=None, request_class=None, call_class=None, **kwargs):
+    def __init__(self, controller_prefix='', interface_class=None, server_class=None, \
+                 request_class=None, response_class=None, call_class=None, **kwargs):
         if controller_prefix:
             self.controller_prefix = controller_prefix
         if not self.controller_prefix:
@@ -59,6 +70,9 @@ class BaseServer(object):
         if request_class:
             self.request_class = request_class
 
+        if response_class:
+            self.response_class = response_class
+
         if call_class:
             self.call_class = call_class
 
@@ -68,6 +82,7 @@ class BaseServer(object):
     def create_interface(self, **kwargs):
         kwargs.setdefault('call_class', self.call_class)
         kwargs.setdefault('request_class', self.request_class)
+        kwargs.setdefault('response_class', self.response_class)
         kwargs.setdefault('controller_prefix', self.controller_prefix)
         return self.interface_class(**kwargs)
 
